/*
This file is part of Choqok, the KDE micro-blogging client

Copyright (C) 2010-2012 Mehrdad Momeny <mehrdad.momeny@gmail.com>
Copyright (C) 2010 Scott Banwart <sbanwart@rogue-technology.com>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License or (at your option) version 3 or any later version
accepted by the membership of KDE e.V. (or its successor approved
by the membership of KDE e.V.), which shall act as a proxy
defined in Section 14 of version 3 of the license.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see http://www.gnu.org/licenses/
*/
#ifndef UR_LY_H
#define UR_LY_H

#include <QVariantList>
#include <QUrlQuery>

#include "shortener.h"

/**
@author Scott Banwart \<sbanwart@rogue-technology.com\>
*/
class Ur_ly : public Choqok::Shortener
{
    Q_OBJECT
public:
    Ur_ly(QObject *parent, const QVariantList &args);
    ~Ur_ly();

    virtual QString shorten(const QString &url);
};

#endif
